Someone (probably you) recently tried to reset the password for this email on {{ settings.SITE_DOMAIN }}. However, there is no account for this email address. If this was not you, please ignore this message. If it was you, please register at {{ settings.SITE_URL }}{% url "register" %}

Sincerely,
{{ settings.SITE_NAME }} Staff
